extern crate serde;
extern crate serde_yaml;

use std::fs::{File};
use std::path::Path;
use std::io::prelude::*;
use std::process::exit;
use std::env;

use self::serde::{Deserialize};

mod config {}

#[derive(Debug, PartialEq, Deserialize)]
pub struct Config {
    foo: String
}

const CONFIG_FOLDERS: &'static [&'static str] = &["XDG_CONFIG_HOME", "HOME"];

pub fn default_config_file() -> String {
    // TODO cycle through to find config file
    for f in CONFIG_FOLDERS {
        match env::var(f) {
            Err(_) => continue,
            Ok(dir) => {
                let config_file_location = Path::new(&dir).join("/fallout-terminal.yaml");
                if Path::is_file(&config_file_location) {
                    return config_file_location.into_os_string().into_string().unwrap()
                }
            }
        }
    }

    // TODO fallback to HOME/.config
    let config_dir = match env::var("XDG_CONFIG_HOME") {
        Ok(dir) => dir,
        // This will usually be $HOME/.config
        Err(_) => match env::var("HOME") {
            Ok(home) => [home, "/.config".into()].concat(),
            Err(_) => {
                println!("Could not determine config directory");
                exit(1);
            }
        }
    };

    // Throw fallout-terminal.yaml onto that
    let mut config_location = String::from(&config_dir);
    config_location.push_str("/fallout-terminal.yaml");

    config_location
}

pub fn load_config_file(config_file_path: String) -> Config {
    let mut config_file = match File::open(config_file_path.as_str()) {
        Ok(config_file) => config_file,
        Err(e) => {
            println!("Could not open {}: {}", config_file_path, e);
            exit(1);
        }
    };

    // TODO Use serde instead
    let mut config_str = String::new();
    match config_file.read_to_string(&mut config_str) {
        Ok(_) => {
            let config: Config = match serde_yaml::from_str(&config_str) {
                Ok(conf) => conf,
                Err(e) => {
                    println!("Could not parse YAML in {}: {}", config_file_path, e);
                    exit(1);
                }
            };
            return config
        }
        Err(e) => {
            println!("Could not read {}: {}", config_file_path, e);
            exit(1);
        }
    };

    // DEBUG: seeing yaml values
    // let mut out_str = String::new();
    // let mut emitter = YamlEmitter::new(&mut out_str);
    // for x in &config {
    //     println!("{:?}", emitter.dump(x).unwrap());
    // }
}
