extern crate pancurses;
use self::pancurses::{
    initscr, endwin, noecho, has_colors, start_color, init_pair,
    Window,
    COLOR_GREEN, COLOR_BLACK
};
use std::{thread, time};

// Screen control functionality. Essentially just handling the heavy lifting
// pancurses involves.

// A Screen object here is just a wrapper around pancurses' Window.

mod screen {}

pub struct Screen {
    pub w: Window
}


pub fn init_screen() -> Screen {
    let window = initscr();
    noecho();
    window_enable_colors();
    Screen{w: window}
}

impl Screen {
    pub fn intro (&self) {
        self.w.clear();
        thread::sleep(time::Duration::from_millis(250));
        self.slow_print(0, String::from("WELCOME TO ROBCO INDUSTRIES (TM) TERMLINK"));

        self.w.mv(1, 0);
        self.w.refresh();
        thread::sleep(time::Duration::from_millis(30));
    }

    pub fn end_window(&self) {
        endwin();
    }

    fn slow_print(&self, line: i32, string: String) {
        self.w.mv(line, 0);
        for c in string.chars() {
            self.w.addch(c);
            self.w.refresh();
            // TODO keyboard skip
            thread::sleep(time::Duration::from_millis(20));
        }
    }
}

fn window_enable_colors() {
    if has_colors() {
        start_color();
        init_pair(1, COLOR_GREEN, COLOR_BLACK);
    }
}
